@@ -13,7 +13,7 @@ pub_key = """-----BEGIN PUBLIC KEY-----
  -----END PUBLIC KEY-----"""
 
 
-api = MBillsAPI(api_key='22a71a85-3807-4e0b-93ea-f450c4d8981a', shared_secret='9335be75-90c4-41e2-af6f-fefb8028f424', mbills_rsa_pub_key=None, nonce_length=8,
+api = MBillsAPI(api_key='22a71a85-3807-4e0b-93ea-f450c4d8981a', shared_secret='9335be75-90c4-41e2-af6f-fefb8028f424', mbills_rsa_pub_key=pub_key, nonce_length=8,
                 api_endpoint="https://demo3.halcom.com/MBillsWS")
 
 
